# xlwings_utils

## Introduction

 Badges

![PyPI](https://img.shields.io/pypi/v/xlwings_utils) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/xlwings_utils) ![PyPI - Implementation](https://img.shields.io/pypi/implementation/xlwings_utils)
![PyPI - License](https://img.shields.io/pypi/l/xlwings_utils) ![ruff](https://img.shields.io/badge/style-ruff-41B5BE?style=flat) 
![GitHub last commit](https://img.shields.io/github/last-commit/salabim/peek)

